1.0.0
-----

* Repackage to hatch/pyproject
* Port to gpiod (Pi 5 support)

0.0.2
-----

* Values will now always be float
* Fixed backlight pin
* Fixed latest/average mph

0.0.1
-----

* Initial Release
